summaryrefslogtreecommitdiff
path: root/src/lzw.h
diff options
context:
space:
mode:
authorMichael Drake <tlsa@netsurf-browser.org>2021-03-31 21:17:58 +0100
committerMichael Drake <tlsa@netsurf-browser.org>2021-04-06 09:03:19 +0100
commitbf63b51e89777cccbc3e94e3c4ca082f5f82def2 (patch)
treebf647e53eb345f4bb09c31cd36b42fb55cba2ed6 /src/lzw.h
parentc06164add4d44baad937ee9abcd110a46b7944ba (diff)
downloadlibnsgif-bf63b51e89777cccbc3e94e3c4ca082f5f82def2.tar.gz
libnsgif-bf63b51e89777cccbc3e94e3c4ca082f5f82def2.tar.bz2
lzw: Rename minimum_code_size to match what it's called in spec.
Diffstat (limited to 'src/lzw.h')
-rw-r--r--src/lzw.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lzw.h b/src/lzw.h
index 385b425..888526e 100644
--- a/src/lzw.h
+++ b/src/lzw.h
@@ -65,7 +65,7 @@ void lzw_context_destroy(
* \param[in] compressed_data_len Byte length of compressed data.
* \param[in] compressed_data_pos Start position in data. Must be position
* of a size byte at sub-block start.
* \param[in] code_size The initial LZW code size to use.
* \param[out] stack_base_out Returns base of decompressed data stack.
* \param[out] stack_pos_out Returns current stack position.
* There are `stack_pos_out - stack_base_out`
@@ -77,7 +77,7 @@ lzw_result lzw_decode_init(
const uint8_t *compressed_data,
uint32_t compressed_data_len,
uint32_t compressed_data_pos,
- uint8_t code_size,
+ uint8_t minimum_code_size,
const uint8_t ** const stack_base_out,
const uint8_t ** const stack_pos_out);
@@ -65,7 +65,7 @@ void lzw_context_destroy(
* \param[in] compressed_data_pos Start position in data. Must be position
* of a size byte at sub-block start.
- * \param[in] code_size The initial LZW code size to use.
+ * \param[in] minimum_code_size The LZW Minimum Code Size.
* \param[out] stack_base_out Returns base of decompressed data stack.
* \param[out] stack_pos_out Returns current stack position.